import React from 'react'
import Head from 'next/head'
import Nav from '../components/nav'
import Sidebar from '../components/sidebar'
import Poll from '../components/poll'
import Training from '../components/training'
import { TrainingArchive } from '../components/training'
import Exercise from '../components/exercise'
import { ExerciseList } from '../components/exercise'
import { PeopleList } from '../components/people'
import data from '../initial-data.js'

const Home = () => (
  <div>
    <Head>
      <title>Home</title>
      <link
        href='https://fonts.googleapis.com/css?family=Noto+Sans&display=swap'
        rel='stylesheet'
      />
      <link rel='icon' href='/favicon.ico' />
    </Head>

    <Nav />
    <Sidebar />
    <div id='content'>
      <Poll />
      <TrainingArchive trainings={data.trainings} />
      <ExerciseList exercises={data.exercises} />
      <PeopleList people={data.people} />
      <Training training={data.trainings[data.trainings.length - 1]} />
    </div>

    <style jsx>{`
      :global(html) {
        font-family: 'Noto Sans', sans-serif;
        box-sizing: border-box;
      }

      :global(*),
      :global(*:before),
      :global(*:after) {
        box-sizing: inherit;
      }

      :global(body) {
        display: grid;
        grid-template-columns: 250px 1fr;
        grid-template-areas:
          'header header'
          'sidebar content';
      }

      #content {
        grid-area: content;
      }
    `}</style>
  </div>
)

export default Home
